@@ -131,7 +131,12 @@ class FileNameValidator(BaseValidator):
         )
 
     def validate(self, value: PathType) -> None:
-        validate_pathtype(value, allow_whitespaces=True if not self._is_windows() else False)
+        validate_pathtype(
+            value,
+            allow_whitespaces=False
+            if self.platform in [Platform.UNIVERSAL, Platform.WINDOWS]
+            else True,
+        )
 
         unicode_filename = preprocess(value)
         value_len = len(unicode_filename)
@@ -155,12 +160,18 @@ class FileNameValidator(BaseValidator):
             self.__validate_unix_filename(unicode_filename)
 
     def validate_abspath(self, value: str) -> None:
-        if any([ntpath.isabs(value), posixpath.isabs(value)]):
-            raise ValidationError(
-                description="found an absolute path ({}), expected a filename".format(value),
-                platform=self.platform,
-                reason=ErrorReason.FOUND_ABS_PATH,
-            )
+        err = ValidationError(
+            description="found an absolute path ({}), expected a filename".format(value),
+            platform=self.platform,
+            reason=ErrorReason.FOUND_ABS_PATH,
+        )
+
+        if self._is_universal() or self._is_windows():
+            if ntpath.isabs(value):
+                raise err
+
+        if posixpath.isabs(value):
+            raise err
 
     def __validate_unix_filename(self, unicode_filename: str) -> None:
         match = _RE_INVALID_FILENAME.findall(unicode_filename)
@@ -295,7 +306,7 @@ def sanitize_filename(
             - for Windows (or universal) only: |invalid_win_filename_chars|
 
         - Append underscore (``"_"``) at the tail of the name if sanitized name
-          is one of the reserved names by the operating system
+          is one of the reserved names by operating systems
           (only when ``check_reserved`` is |True|).
 
     Args:
