@@ -163,7 +163,12 @@ class FilePathValidator(BaseValidator):
             self.__split_drive = posixpath.splitdrive
 
     def validate(self, value: PathType) -> None:
-        validate_pathtype(value, allow_whitespaces=True if not self._is_windows() else False)
+        validate_pathtype(
+            value,
+            allow_whitespaces=False
+            if self.platform in [Platform.UNIVERSAL, Platform.WINDOWS]
+            else True,
+        )
         self.validate_abspath(value)
 
         _drive, value = self.__split_drive(str(value))
@@ -373,7 +378,7 @@ def sanitize_filepath(
             - for Windows (or universal) only: |invalid_win_file_path_chars|
 
         - Append underscore (``"_"``) at the tail of the name if sanitized name
-          is one of the reserved names by the operating system
+          is one of the reserved names by operating systems
           (only when ``check_reserved`` is |True|).
 
     Args:
